// sd-timer/includes/script.js
jQuery(document).ready(function($) {
    let sessionStart = new Date();
    let sessionTime = 0;
    let totalTime = 0;
    let timerSettings = null;
    let timerInterval;
    
    // Initialize timers
    function initializeTimers() {
        const today = new Date().toLocaleDateString();
        const lastLoginDate = localStorage.getItem('sdtimer_last_login');
        
        if (lastLoginDate !== today) {
            // First login of the day
            sessionTime = 0;
            totalTime = 0;
            localStorage.setItem('sdtimer_last_login', today);
        } else {
            // Get saved total time
            $.ajax({
                url: sdtimerData.ajaxurl,
                type: 'POST',
                data: {
                    action: 'sdtimer_get_time',
                    nonce: sdtimerData.nonce
                },
                success: function(response) {
                    if (response.success) {
                        totalTime = parseInt(response.data.total_time) || 0;
                        timerSettings = response.data.timer_settings ? JSON.parse(response.data.timer_settings) : null;
                        updateTimerDisplay();
                    }
                }
            });
        }
        
        startTimer();
    }
    
    // Start timer
    function startTimer() {
        timerInterval = setInterval(function() {
            sessionTime = Math.floor((new Date() - sessionStart) / 1000);
            updateTimerDisplay();
            saveTimerData();
        }, 1000);
    }
    
    // Update timer display
    function updateTimerDisplay() {
        const sessionDisplay = formatTime(sessionTime);
        // Only display the saved total time, don't add current session time
        const totalDisplay = formatTime(totalTime);
        
        $('#sdtimer-session-counter').text(sessionDisplay);
        $('#sdtimer-total-counter').text(totalDisplay);
        
        // Update counter colors based on timer settings
        if (timerSettings) {
            const targetSeconds = (timerSettings.hours * 3600) + (timerSettings.minutes * 60);
            // Use total + session time for color calculation
            const currentTotalSeconds = totalTime + sessionTime;
            
            $('.sdtimer-counter').removeClass('time-exceeded time-remaining');
            if (currentTotalSeconds >= targetSeconds) {
                $('.sdtimer-counter').addClass('time-exceeded');
            } else {
                $('.sdtimer-counter').addClass('time-remaining');
            }
        }
    }
    
    // Format time as HH:MM:SS
    function formatTime(seconds) {
        const h = Math.floor(seconds / 3600);
        const m = Math.floor((seconds % 3600) / 60);
        const s = seconds % 60;
        return `${padZero(h)}:${padZero(m)}:${padZero(s)}`;
    }
    
    // Add leading zero
    function padZero(num) {
        return num.toString().padStart(2, '0');
    }
    
    // Save timer data
    function saveTimerData() {
        $.ajax({
            url: sdtimerData.ajaxurl,
            type: 'POST',
            data: {
                action: 'sdtimer_save_time',
                nonce: sdtimerData.nonce,
                session_time: sessionTime,
                total_time: totalTime, // Don't add session time here
                timer_settings: timerSettings ? JSON.stringify(timerSettings) : null
            }
        });
    }
    
    // Handle timer settings
    $('#sdtimer-save').on('click', function() {
        const hours = parseInt($('#working-hours').val()) || 0;
        const minutes = parseInt($('#working-minutes').val()) || 0;
        
        timerSettings = { hours, minutes };
        saveTimerData();
        updateTimerDisplay();
    });
    
    // Handle page unload
    $(window).on('beforeunload', function() {
        // Add current session time to total before saving
        totalTime += sessionTime;
        saveTimerData();
        clearInterval(timerInterval);
    });
    
    // Initialize on page load
    initializeTimers();
});