<?php
/*
Plugin Name: SD Timer - Free Time Tracker
Description: Track your daily working time on wordpress frontend and backend.
Version: 1.0.0
Requires at least: 6.7
Requires PHP: 7.2
Author: Sadhan Pal
Author URI: https://bloggingfoundation.com/
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

if (!defined('ABSPATH')) {
    exit;
}

// Enqueue scripts and styles
function sdtimer_enqueue_scripts() {
    if (is_user_logged_in()) {
        wp_enqueue_style('sdtimer-style', plugins_url('includes/style.css', __FILE__));
        wp_enqueue_script('sdtimer-script', plugins_url('includes/script.js', __FILE__), array('jquery'), '1.0', true);
        
        // Pass data to JavaScript
        wp_localize_script('sdtimer-script', 'sdtimerData', array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('sdtimer-nonce'),
            'userTime' => current_time('mysql'),
        ));
    }
}
add_action('wp_enqueue_scripts', 'sdtimer_enqueue_scripts');
add_action('admin_enqueue_scripts', 'sdtimer_enqueue_scripts');

// Add menu item
function sdtimer_add_menu() {
    add_menu_page(
        'SD Timer',
        'SD Timer',
        'manage_options',
        'sd-timer',
        'sdtimer_settings_page',
        'dashicons-clock',
        3                   // Position (3 = after Dashboard)
    );
}
add_action('admin_menu', 'sdtimer_add_menu');

// Create settings page
function sdtimer_settings_page() {
    ?>
    <div class="wrap">
        <h1>SD Timer Settings</h1>
        <div class="sdtimer-settings-container">
            <h2>Set Timer</h2>
            <div class="sdtimer-form">
                <div class="sdtimer-input-group">
                    <label for="working-hours">Working Period (Hours)</label>
                    <input type="number" id="working-hours" min="0" max="23" value="0">
                </div>
                <div class="sdtimer-input-group">
                    <label for="working-minutes">Working Period (Minutes)</label>
                    <input type="number" id="working-minutes" min="0" max="59" value="0">
                </div>
                <button id="sdtimer-save" class="button button-primary">Save Timer</button>
            </div>
        </div>
    </div>
    <?php
}

// Add counters to admin bar
function sdtimer_add_toolbar_items($admin_bar) {
    if (is_user_logged_in()) {
        $admin_bar->add_node(array(
            'id' => 'sdtimer-session',
            'title' => 'You are working for: <span id="sdtimer-session-counter">00:00:00</span>',
            'href' => '#',
            'meta' => array(
                'class' => 'sdtimer-counter'
            )
        ));
        
        $admin_bar->add_node(array(
            'id' => 'sdtimer-total',
            'title' => 'Today total: <span id="sdtimer-total-counter">00:00:00</span>',
            'href' => '#',
            'meta' => array(
                'class' => 'sdtimer-counter'
            )
        ));
    }
}
add_action('admin_bar_menu', 'sdtimer_add_toolbar_items', 500);

// AJAX handlers for saving/retrieving timer data
function sdtimer_save_time() {
    check_ajax_referer('sdtimer-nonce', 'nonce');
    
    $user_id = get_current_user_id();
$session_time = isset($_POST['session_time']) 
    ? intval(sanitize_text_field($_POST['session_time'])) 
    : 0;
$total_time = isset($_POST['total_time']) 
    ? intval(sanitize_text_field($_POST['total_time'])) 
    : 0;
$timer_settings = isset($_POST['timer_settings']) 
    ? wp_kses_post($_POST['timer_settings']) 
    : null;

// Additional validation
if ($session_time < 0) $session_time = 0;
if ($total_time < 0) $total_time = 0;
    
    update_user_meta($user_id, 'sdtimer_session_time', $session_time);
    update_user_meta($user_id, 'sdtimer_total_time', $total_time);
    update_user_meta($user_id, 'sdtimer_settings', $timer_settings);
    
    wp_send_json_success();
}
add_action('wp_ajax_sdtimer_save_time', 'sdtimer_save_time');

function sdtimer_get_time() {
    check_ajax_referer('sdtimer-nonce', 'nonce');
    
    $user_id = get_current_user_id();
    $data = array(
        'session_time' => get_user_meta($user_id, 'sdtimer_session_time', true),
        'total_time' => get_user_meta($user_id, 'sdtimer_total_time', true),
        'timer_settings' => get_user_meta($user_id, 'sdtimer_settings', true)
    );
    
    wp_send_json_success($data);
}
add_action('wp_ajax_sdtimer_get_time', 'sdtimer_get_time');